@@ -572,6 +572,25 @@ static int32_t mdcache_fs_expiretimeparent(struct fsal_export *exp_hdl)
 	return result;
 }
 
+/**
+ * @brief Get the configured readdir modes for parent handle
+ *
+ * @param[in] exp_hdl   Export to query
+ * @return Readdir modes for parent handle
+ */
+static enum fsal_readdir_mode
+mdcache_fs_readdir_mode(struct fsal_export *exp_hdl)
+{
+	struct mdcache_fsal_export *exp = mdc_export(exp_hdl);
+	struct fsal_export *sub_export = exp->mfe_exp.sub_export;
+	int32_t result;
+
+	subcall_raw(exp,
+		    result = sub_export->exp_ops.fs_readdir_mode(sub_export));
+
+	return result;
+}
+
 /**
  * @brief Check quota on a file
  *
@@ -924,6 +943,7 @@ void mdcache_export_ops_init(struct export_ops *ops)
 	ops->alloc_state = mdcache_alloc_state;
 	ops->is_superuser = mdcache_is_superuser;
 	ops->fs_expiretimeparent = mdcache_fs_expiretimeparent;
+	ops->fs_readdir_mode = mdcache_fs_readdir_mode;
 }
 
 #if 0
