@@ -54,13 +54,16 @@
  * @param[out] end_of_list	True if reached end of list
  * @return FSAL status
  */
-fsal_status_t
-mdcache_list_ext_attrs(struct fsal_obj_handle *obj_hdl, unsigned int argcookie,
-		       fsal_xattrent_t *xattrs_tab, unsigned int xattrs_tabsize,
-		       unsigned int *p_nb_returned, int *end_of_list)
+fsal_status_t mdcache_list_ext_attrs(struct fsal_obj_handle *obj_hdl,
+				     unsigned int argcookie,
+				     fsal_xattrent_t *xattrs_tab,
+				     unsigned int xattrs_tabsize,
+				     unsigned int *p_nb_returned,
+				     int *end_of_list)
 {
-	struct mdcache_fsal_obj_handle *handle = container_of(
-		obj_hdl, struct mdcache_fsal_obj_handle, obj_handle);
+	struct mdcache_fsal_obj_handle *handle =
+		container_of(obj_hdl, struct mdcache_fsal_obj_handle,
+			     obj_handle);
 	fsal_status_t status;
 
 	subcall(status = handle->sub_handle->obj_ops->list_ext_attrs(
@@ -84,8 +87,9 @@ fsal_status_t mdcache_getextattr_id_by_name(struct fsal_obj_handle *obj_hdl,
 					    const char *name,
 					    unsigned int *p_id)
 {
-	struct mdcache_fsal_obj_handle *handle = container_of(
-		obj_hdl, struct mdcache_fsal_obj_handle, obj_handle);
+	struct mdcache_fsal_obj_handle *handle =
+		container_of(obj_hdl, struct mdcache_fsal_obj_handle,
+			     obj_handle);
 	fsal_status_t status;
 
 	subcall(status = handle->sub_handle->obj_ops->getextattr_id_by_name(
@@ -111,8 +115,9 @@ fsal_status_t mdcache_getextattr_value_by_id(struct fsal_obj_handle *obj_hdl,
 					     size_t buf_size,
 					     size_t *p_output_size)
 {
-	struct mdcache_fsal_obj_handle *handle = container_of(
-		obj_hdl, struct mdcache_fsal_obj_handle, obj_handle);
+	struct mdcache_fsal_obj_handle *handle =
+		container_of(obj_hdl, struct mdcache_fsal_obj_handle,
+			     obj_handle);
 	fsal_status_t status;
 
 	subcall(status = handle->sub_handle->obj_ops->getextattr_value_by_id(
@@ -138,8 +143,9 @@ fsal_status_t mdcache_getextattr_value_by_name(struct fsal_obj_handle *obj_hdl,
 					       size_t buf_size,
 					       size_t *p_output_size)
 {
-	struct mdcache_fsal_obj_handle *handle = container_of(
-		obj_hdl, struct mdcache_fsal_obj_handle, obj_handle);
+	struct mdcache_fsal_obj_handle *handle =
+		container_of(obj_hdl, struct mdcache_fsal_obj_handle,
+			     obj_handle);
 	fsal_status_t status;
 
 	subcall(status = handle->sub_handle->obj_ops->getextattr_value_by_name(
@@ -165,8 +171,9 @@ fsal_status_t mdcache_setextattr_value(struct fsal_obj_handle *obj_hdl,
 				       const char *name, void *buf,
 				       size_t buf_size, int create)
 {
-	struct mdcache_fsal_obj_handle *handle = container_of(
-		obj_hdl, struct mdcache_fsal_obj_handle, obj_handle);
+	struct mdcache_fsal_obj_handle *handle =
+		container_of(obj_hdl, struct mdcache_fsal_obj_handle,
+			     obj_handle);
 	fsal_status_t status;
 
 	subcall(status = handle->sub_handle->obj_ops->setextattr_value(
@@ -190,8 +197,9 @@ fsal_status_t mdcache_setextattr_value_by_id(struct fsal_obj_handle *obj_hdl,
 					     unsigned int id, void *buf,
 					     size_t buf_size)
 {
-	struct mdcache_fsal_obj_handle *handle = container_of(
-		obj_hdl, struct mdcache_fsal_obj_handle, obj_handle);
+	struct mdcache_fsal_obj_handle *handle =
+		container_of(obj_hdl, struct mdcache_fsal_obj_handle,
+			     obj_handle);
 	fsal_status_t status;
 
 	subcall(status = handle->sub_handle->obj_ops->setextattr_value_by_id(
@@ -212,8 +220,9 @@ fsal_status_t mdcache_setextattr_value_by_id(struct fsal_obj_handle *obj_hdl,
 fsal_status_t mdcache_remove_extattr_by_id(struct fsal_obj_handle *obj_hdl,
 					   unsigned int id)
 {
-	struct mdcache_fsal_obj_handle *handle = container_of(
-		obj_hdl, struct mdcache_fsal_obj_handle, obj_handle);
+	struct mdcache_fsal_obj_handle *handle =
+		container_of(obj_hdl, struct mdcache_fsal_obj_handle,
+			     obj_handle);
 	fsal_status_t status;
 
 	subcall(status = handle->sub_handle->obj_ops->remove_extattr_by_id(
@@ -234,8 +243,9 @@ fsal_status_t mdcache_remove_extattr_by_id(struct fsal_obj_handle *obj_hdl,
 fsal_status_t mdcache_remove_extattr_by_name(struct fsal_obj_handle *obj_hdl,
 					     const char *name)
 {
-	struct mdcache_fsal_obj_handle *handle = container_of(
-		obj_hdl, struct mdcache_fsal_obj_handle, obj_handle);
+	struct mdcache_fsal_obj_handle *handle =
+		container_of(obj_hdl, struct mdcache_fsal_obj_handle,
+			     obj_handle);
 	fsal_status_t status;
 
 	subcall(status = handle->sub_handle->obj_ops->remove_extattr_by_name(
@@ -257,8 +267,9 @@ fsal_status_t mdcache_remove_extattr_by_name(struct fsal_obj_handle *obj_hdl,
 fsal_status_t mdcache_getxattrs(struct fsal_obj_handle *obj_hdl,
 				xattrkey4 *name, xattrvalue4 *value)
 {
-	struct mdcache_fsal_obj_handle *handle = container_of(
-		obj_hdl, struct mdcache_fsal_obj_handle, obj_handle);
+	struct mdcache_fsal_obj_handle *handle =
+		container_of(obj_hdl, struct mdcache_fsal_obj_handle,
+			     obj_handle);
 	fsal_status_t status;
 
 	subcall(status = handle->sub_handle->obj_ops->getxattrs(
@@ -282,8 +293,9 @@ fsal_status_t mdcache_setxattrs(struct fsal_obj_handle *obj_hdl,
 				setxattr_option4 option, xattrkey4 *name,
 				xattrvalue4 *value)
 {
-	struct mdcache_fsal_obj_handle *handle = container_of(
-		obj_hdl, struct mdcache_fsal_obj_handle, obj_handle);
+	struct mdcache_fsal_obj_handle *handle =
+		container_of(obj_hdl, struct mdcache_fsal_obj_handle,
+			     obj_handle);
 	fsal_status_t status;
 
 	subcall(status = handle->sub_handle->obj_ops->setxattrs(
@@ -304,8 +316,9 @@ fsal_status_t mdcache_setxattrs(struct fsal_obj_handle *obj_hdl,
 fsal_status_t mdcache_removexattrs(struct fsal_obj_handle *obj_hdl,
 				   xattrkey4 *name)
 {
-	struct mdcache_fsal_obj_handle *handle = container_of(
-		obj_hdl, struct mdcache_fsal_obj_handle, obj_handle);
+	struct mdcache_fsal_obj_handle *handle =
+		container_of(obj_hdl, struct mdcache_fsal_obj_handle,
+			     obj_handle);
 	fsal_status_t status;
 
 	subcall(status = handle->sub_handle->obj_ops->removexattrs(
@@ -331,8 +344,9 @@ fsal_status_t mdcache_listxattrs(struct fsal_obj_handle *obj_hdl, count4 len,
 				 nfs_cookie4 *cookie, bool_t *eof,
 				 xattrlist4 *names)
 {
-	struct mdcache_fsal_obj_handle *handle = container_of(
-		obj_hdl, struct mdcache_fsal_obj_handle, obj_handle);
+	struct mdcache_fsal_obj_handle *handle =
+		container_of(obj_hdl, struct mdcache_fsal_obj_handle,
+			     obj_handle);
 	fsal_status_t status;
 
 	subcall(status = handle->sub_handle->obj_ops->listxattrs(
