@@ -763,7 +763,8 @@ void qos_drain_iops_ios(qos_class_t *qos_class)
 void qos_drain_ios(qos_class_t *qos_class)
 {
 	if (!qos_class)
-		LogCrit(COMPONENT_QOS, "NULL QOS class passed to drain IO's");
+		return;
+
 	QOS_PRINT_CLASS(__func__, qos_class);
 	PTHREAD_MUTEX_lock(&(qos_class->lock));
 	qos_drain_token_ios(qos_class);
@@ -786,9 +787,12 @@ bool pepc_per_export_free_mem_iter(struct gsh_export *gsh_export, void *state)
 	qos_class_t *qos_class = gsh_export->qos_class;
 	qos_class_t *sub_qos_class = NULL;
 
+	if (!qos_class)
+		return true;
+
 	PTHREAD_MUTEX_lock(&qos_class->lock);
 	/* list is not populated */
-	if (!qos_class || glist_empty(&qos_class->clients)) {
+	if (glist_empty(&qos_class->clients)) {
 		PTHREAD_MUTEX_unlock(&qos_class->lock);
 		return true;
 	}
@@ -1114,6 +1118,27 @@ static void update_class_token_values(qos_class_t *qos_class,
 	}
 }
 
+/**
+ * Function to update DS values for a QoS class
+ * This requires parent control(BW/token) to be enabled first.
+ *
+ * @param [in] class Pointer to the QoS export or client object
+ * @param [in] in  New values which are to be applied to DS
+ */
+static void update_class_ds_values(qos_class_t *qos_class,
+				   struct qos_block_config *in)
+{
+	bool *ds_enabled = NULL;
+
+	ds_enabled = &(qos_class->ds_enabled);
+
+	if (g_qos_config->enable_ds_control && in->enable_ds_control) {
+		*ds_enabled = true;
+	} else {
+		*ds_enabled = false;
+	}
+}
+
 /**
  * Function to update BW values for a QoS class
  *
@@ -1239,10 +1264,12 @@ static void set_class_values(qos_class_t *qos_class,
 		in->enable_tokens = false;
 		in->enable_iops_control = false;
 		in->enable_bw_control = false;
+		in->enable_ds_control = false;
 	}
 
 	update_class_token_values(qos_class, in);
 	update_class_bw_values(qos_class, in);
+	update_class_ds_values(qos_class, in);
 	update_class_iops_values(qos_class, in);
 }
 
@@ -1593,8 +1620,7 @@ static void qos_token_exausted_suspend_task(qos_class_t *qos_class,
 		qos_get_time_to_tokenrefresh(qos_class, op_type, ltime);
 
 	timeout = get_time_future_useconds(
-		ltime, MIN(TOKEN_NFS_ERR_DELAY_DEFAULT, time_to_refresh),
-		0, 0);
+		ltime, MIN(TOKEN_NFS_ERR_DELAY_DEFAULT, time_to_refresh), 0, 0);
 
 	client = get_and_insert_client_details(&(qos_class->client_entries),
 					       data);
@@ -1607,8 +1633,9 @@ static void qos_token_exausted_suspend_task(qos_class_t *qos_class,
 		svc_rqst_qos_suspend_socket(client->rq_xprt);
 	} else if (client->num_ios_waiting >= SUSPEND_SOCKET_IO_LIMIT &&
 		   client->epoll_disabled == 1) {
-		timeout = get_time_future_useconds(
-			ltime, TOKEN_NFS_ERR_DELAY_IMMED, 0, 0);
+		timeout = get_time_future_useconds(ltime,
+						   TOKEN_NFS_ERR_DELAY_IMMED, 0,
+						   0);
 	}
 
 	new_timer_entry = create_timer_entry(timeout,
@@ -1733,7 +1760,7 @@ static inline qos_status_t qos_check_pepc(void *class_ptr, uint64_t rsize,
  */
 static inline qos_status_t qos_process_pe(uint64_t rsize, void *caller_data,
 					  compound_data_t *data,
-					  qos_op_type_t op_type)
+					  qos_op_type_t op_type, bool is_ds)
 {
 	if (!op_ctx->ctx_export->qos_class) {
 		PTHREAD_MUTEX_lock(&g_qos_iopath_lock);
@@ -1742,6 +1769,8 @@ static inline qos_status_t qos_process_pe(uint64_t rsize, void *caller_data,
 
 		PTHREAD_MUTEX_unlock(&g_qos_iopath_lock);
 	}
+	if (is_ds && !op_ctx->ctx_export->qos_class->ds_enabled)
+		return QOS_TASK_NOT_SUSPENDED;
 	return qos_check_pe_pc(op_ctx->ctx_export->qos_class, rsize, op_type,
 			       caller_data, data);
 }
@@ -1758,7 +1787,7 @@ static inline qos_status_t qos_process_pe(uint64_t rsize, void *caller_data,
  */
 static inline qos_status_t qos_process_pc(uint64_t rsize, void *caller_data,
 					  compound_data_t *data,
-					  qos_op_type_t op_type)
+					  qos_op_type_t op_type, bool is_ds)
 {
 	if (!op_ctx->client->qos_class) {
 		PTHREAD_MUTEX_lock(&g_qos_iopath_lock);
@@ -1768,6 +1797,8 @@ static inline qos_status_t qos_process_pc(uint64_t rsize, void *caller_data,
 
 		PTHREAD_MUTEX_unlock(&g_qos_iopath_lock);
 	}
+	if (is_ds && !op_ctx->client->qos_class->ds_enabled)
+		return QOS_TASK_NOT_SUSPENDED;
 	return qos_check_pe_pc(op_ctx->client->qos_class, rsize, op_type,
 			       caller_data, data);
 }
@@ -1784,7 +1815,7 @@ static inline qos_status_t qos_process_pc(uint64_t rsize, void *caller_data,
  */
 static inline qos_status_t qos_process_pepc(uint64_t rsize, void *caller_data,
 					    compound_data_t *data,
-					    qos_op_type_t op_type)
+					    qos_op_type_t op_type, bool is_ds)
 {
 	qos_class_t *qos_class = op_ctx->ctx_export->qos_class;
 	qos_status_t ret = QOS_TASK_NOT_SUSPENDED;
@@ -1804,6 +1835,8 @@ static inline qos_status_t qos_process_pepc(uint64_t rsize, void *caller_data,
 		}
 		PTHREAD_MUTEX_unlock(&g_qos_iopath_lock);
 	}
+	if (is_ds && !qos_class->ds_enabled)
+		return ret;
 	/* Is QOS disabled for this particular export */
 	if (qos_class->bw_enabled || qos_class->token_enabled) {
 		/* func call reassures the client is the in export list */
@@ -1821,27 +1854,33 @@ static inline qos_status_t qos_process_pepc(uint64_t rsize, void *caller_data,
  * @param [in] data Pointer to the compound_data_t structure containing
  *			the request data.
  * @param [in] op_type Type of the operation (read/write).
+ * @param [in] is_ds Whether caller is doing a DS read/write.
  * @return : QOS_TASK_NOT_SUSPENDED/ QOS_TASK_SUSPENDED
  */
 qos_status_t qos_process(uint64_t rsize, void *caller_data,
-			 compound_data_t *data, qos_op_type_t op_type)
+			 compound_data_t *data, qos_op_type_t op_type,
+			 bool is_ds)
 {
 	qos_status_t ret = QOS_TASK_NOT_SUSPENDED;
 
 	if (!g_qos_config->enable_qos)
 		return ret;
 
+	if (is_ds && !g_qos_config->enable_ds_control)
+		return ret;
+
 	switch (g_qos_config->qos_type) {
 	case QOS_NOT_ENABLED:
 		break;
 	case QOS_PER_EXPORT_ENABLED:
-		ret = qos_process_pe(rsize, caller_data, data, op_type);
+		ret = qos_process_pe(rsize, caller_data, data, op_type, is_ds);
 		break;
 	case QOS_PER_CLIENT_ENABLED:
-		ret = qos_process_pc(rsize, caller_data, data, op_type);
+		ret = qos_process_pc(rsize, caller_data, data, op_type, is_ds);
 		break;
 	case QOS_PEREXPORT_PERCLIENT_ENABLED:
-		ret = qos_process_pepc(rsize, caller_data, data, op_type);
+		ret = qos_process_pepc(rsize, caller_data, data, op_type,
+				       is_ds);
 		break;
 	default:
 		LogDebug(COMPONENT_QOS, " INVALID QOS_TYPE: %d",
