@@ -549,10 +549,10 @@ void nfs_try_lift_grace(void)
 	 */
 	PTHREAD_MUTEX_lock(&grace_mutex);
 	rc_count = atomic_fetch_int32_t(&reclaim_completes);
-	LogEvent(COMPONENT_STATE,
-		 "check grace:reclaim complete(%d)"
-		 " clid count(%d)",
-		 rc_count, clid_count);
+	if (clid_count > 0)
+		LogEvent(COMPONENT_STATE,
+			 "check grace:reclaim complete(%d) clid count(%d)",
+			 rc_count, clid_count);
 #ifdef _USE_NLM
 	if (!nfs_param.core_param.enable_NLM)
 #endif
