@@ -883,6 +883,12 @@ nfsstat4 handle_deleg_getattr(struct fsal_obj_handle *obj,
 			      nfs_client_id_t *client);
 int cbgetattr_impl(struct fsal_obj_handle *obj, nfs_client_id_t *client,
 		   struct gsh_export *ctx_exp);
+bool is_stateid_revoked(const stateid4 *stateid);
+void remove_revoked_stateid(const stateid4 *stateid);
+void mark_sessions_have_revoked_delegations(nfs_client_id_t *clientid);
+bool has_revoked_delegations_for_client(nfs_client_id_t *clientid);
+bool atomic_remove_revoked_and_clear_flags(const stateid4 *stateid,
+					   nfs_client_id_t *clientid);
 
 /**
  * @brief Decrement g_total_num_files_delegated if the file has no delegations
